@@ -1,5 +1,7 @@
 template_tabularray <- function(theme = "default") {
-  if (theme == "default") {
+  out <- readLines(system.file("templates/tabularray_default.tex", package = "tinytable"))
+  return(out)
+  if (theme %in% c("default", "grid")) {
     out <- readLines(system.file("templates/tabularray_default.tex", package = "tinytable"))
   } else if (theme == "bootstrap") {
     out <- readLines(system.file("templates/tabularray_bootstrap.tex", package = "tinytable"))
@@ -10,5 +12,4 @@ template_tabularray <- function(theme = "default") {
   } else if (theme == "grid") {
     out <- readLines(system.file("templates/tabularray_grid.tex", package = "tinytable"))
   }
-  return(out)
 }
